.. portfolio_optimizer documentation master file, created by
   sphinx-quickstart on Sat Jan 14 13:02:49 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to portfolio_optimizer!
===============================

.. toctree::
   :maxdepth: 2
   :caption: Contents:  

   modules

.. mdinclude:: ../README.md


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
